pub struct AccessRequestResultView {
pub approval_mode: AccessApprovalMode,
pub request: AccessRequestSummaryView,
}Expand description
The result of submitting a cipher-lease request.
No lease is minted at submit on either path - the requester
activates the request to start the lease.
Fields
approval_mode: AccessApprovalModeAutomatic when request was approved
on submit and is ready to activate, Human when it is
pending an approver.
request: AccessRequestSummaryViewThe request that was just submitted.